import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
var MAX_LABEL_LENGTH = 100;
var TRANSPARENT = 'transparent';
var SIZES = {
  LARGE: 'large',
  MEDIUM: 'medium',
  SMALL: 'small'
};
var TYPES = {
  SUCCESS: 'success',
  ERROR: 'error',
  INFO: 'info',
  ALERT: 'alert'
};
var BASE_CLASS = "sui-AtomBadge";
var CLASS_ICON = BASE_CLASS + "-icon";
var CLASS_ICON_RIGHT = CLASS_ICON + "--iconRight";
/**
 * Cuts off exceeded char limit
 * @param  {string} label
 * @return {string}
 */

var truncateText = function truncateText(label) {
  return label.length < MAX_LABEL_LENGTH ? label : label.substr(0, MAX_LABEL_LENGTH);
};
/**
 * @param  {string} options.className
 * @param  {string} options.size
 * @param  {boolean} options.transparent
 * @param  {string} options.type
 * @return {string}
 */


var getClassNames = function getClassNames(_ref) {
  var _cx;

  var className = _ref.className,
      iconRight = _ref.iconRight,
      size = _ref.size,
      transparent = _ref.transparent,
      type = _ref.type;
  var transparentClass = transparent && "--" + TRANSPARENT || '';
  return cx(BASE_CLASS, BASE_CLASS + "-" + size, BASE_CLASS + "-" + type + transparentClass, (_cx = {}, _cx[CLASS_ICON_RIGHT] = iconRight, _cx));
};
/**
 * Small badges with background can't have icon
 * @param  {Object} options.icon
 * @param  {string} options.size
 * @param  {boolean} options.transparent
 * @return {boolean}
 */


var shouldRenderIcon = function shouldRenderIcon(_ref2) {
  var icon = _ref2.icon,
      size = _ref2.size,
      transparent = _ref2.transparent;
  return icon && (size !== SIZES.SMALL || transparent);
};

var AtomBadge = function AtomBadge(_ref3) {
  var icon = _ref3.icon,
      iconRight = _ref3.iconRight,
      label = _ref3.label,
      props = _objectWithoutPropertiesLoose(_ref3, ["icon", "iconRight", "label"]);

  var truncatedLabel = truncateText(label);
  var classNames = getClassNames(props);
  return React.createElement("div", {
    className: classNames
  }, shouldRenderIcon(_objectSpread({
    icon: icon
  }, props)) && !iconRight && React.createElement("span", {
    className: CLASS_ICON
  }, icon), React.createElement("span", {
    className: "sui-AtomBadge-text",
    title: truncatedLabel
  }, label), shouldRenderIcon(_objectSpread({
    icon: icon
  }, props)) && iconRight && React.createElement("span", {
    className: cx(CLASS_ICON, CLASS_ICON_RIGHT)
  }, icon));
};

AtomBadge.displayName = 'AtomBadge';
AtomBadge.defaultProps = {
  size: SIZES.SMALL,
  type: TYPES.SUCCESS
};
export default AtomBadge;
export { TYPES as atomBadgeTypes, SIZES as atomBadgeSizes };